@@ -12,6 +12,7 @@ st_as_sf = function(x, ...) UseMethod("st_as_sf")
 #' @param wkt name or number of the character column that holds WKT encoded geometries
 #' @param dim passed on to \link{st_point} (only when argument coords is given)
 #' @param remove logical; when coords or wkt is given, remove these columns from data.frame?
+#' @param na.fail logical; if \code{TRUE}, raise an error if coordinates contain missing values
 #' @param ... passed on to \link{st_sf}, might included crs
 #' @details setting argument \code{wkt} annihilates the use of argument \code{coords}. If \code{x} contains a column called "geometry", \code{coords} will result in overwriting of this column by the \link{sfc} geometry list-column.  Setting \code{wkt} will replace this column with the geometry list-column, unless \code{remove_coordinates} is \code{FALSE}.
 #' 
@@ -32,13 +33,15 @@ st_as_sf = function(x, ...) UseMethod("st_as_sf")
 #' summary(meuse_sf)
 #' @export
 st_as_sf.data.frame = function(x, ..., agr = NA_agr_, coords, wkt, 
-		dim = "XYZ", remove = TRUE) {
+		dim = "XYZ", remove = TRUE, na.fail = TRUE) {
 	if (! missing(wkt)) {
 		if (remove) 
 			x[[wkt]] = st_as_sfc(as.character(x[[wkt]]))
 		else
 			x$geometry = st_as_sfc(as.character(x[[wkt]]))
 	} else if (! missing(coords)) {
+		if (na.fail && any(is.na(x[coords])))
+			stop("missing values in coordinates not allowed")
 		classdim = getClassDim(rep(0, length(coords)), length(coords), dim, "POINT")
 		x$geometry = structure( lapply(split(as.vector(t(as.matrix(x[, coords]))), 
 				rep(seq_len(nrow(x)), each = length(coords))), 
@@ -145,7 +148,6 @@ st_geometry.sfg = function(obj, ...) st_sfc(obj)
 		x[[attr(x, "sf_column")]] <- value
 
 	if (is.null(value))
-		# as.data.frame(x)
 		structure(x, sf_column = NULL, agr = NULL, class = setdiff(class(x), "sf"))
 	else
 		x
@@ -189,11 +191,15 @@ list_column_to_sfc = function(x) {
 #' st_sf(a=3,g)
 #' st_sf(g, a=3)
 #' st_sf(a=3, st_sfc(st_point(1:2))) # better to name it!
+#' # create empty structure with preallocated empty geometries:
+#' nrows <- 10
+#' geometry = st_sfc(lapply(1:nrows, function(x) st_geometrycollection()))
+#' df <- st_sf(id = 1:nrows, geometry = geometry)
 #' @export
 st_sf = function(..., agr = NA_agr_, row.names, 
 		stringsAsFactors = default.stringsAsFactors(), crs, precision, sf_column_name = NULL) {
 	x = list(...)
-	if (length(x) == 1L && (inherits(x[[1L]], "data.frame") || is.list(x)))
+	if (length(x) == 1L && (inherits(x[[1L]], "data.frame") || (is.list(x) && !inherits(x[[1L]], "sfc"))))
 		x = x[[1L]]
 
 	# find the sfc column(s):
@@ -261,7 +267,7 @@ st_sf = function(..., agr = NA_agr_, row.names,
 #' @param j variable selection, see \link{[.data.frame}
 #' @param drop logical, default \code{FALSE}; if \code{TRUE} drop the geometry column and return a \code{data.frame}, else make the geometry sticy and return a \code{sf} object.
 #' @param op function; geometrical binary predicate function to apply when \code{i} is a simple feature object
-#' @details "[.sf" will return a \code{data.frame} if the geometry column (of class \code{sfc}) is dropped (\code{drop=TRUE}), an \code{sfc} object if only the geometry column is selected, otherwise returns an \code{sf} object; see also \link{[.data.frame}.
+#' @details \code{[.sf} will return a \code{data.frame} or vector if the geometry column (of class \code{sfc}) is dropped (\code{drop=TRUE}), an \code{sfc} object if only the geometry column is selected, and otherwise return an \code{sf} object; see also \link{[.data.frame}; for \code{[.sf} \code{...} arguments are passed to \code{op}.
 #' @examples
 #' g = st_sfc(st_point(1:2), st_point(3:4))
 #' s = st_sf(a=3:4, g)
@@ -280,8 +286,8 @@ st_sf = function(..., agr = NA_agr_, row.names,
 "[.sf" = function(x, i, j, ..., drop = FALSE, op = st_intersects) {
 	nargs = nargs()
 	agr = st_agr(x)
-	if (!missing(i) && (inherits(i, "sf") || inherits(i, "sfc")))
-		i = lengths(st_intersects(x, i)) != 0
+	if (!missing(i) && (inherits(i, "sf") || inherits(i, "sfc") || inherits(i, "sfg")))
+		i = lengths(op(x, i, ...)) != 0
 	sf_column = attr(x, "sf_column")
 	geom = st_geometry(x)
 	if (!missing(i) && nargs > 2) { # e.g. a[3:4,] not a[3:4]
@@ -320,7 +326,7 @@ st_sf = function(..., agr = NA_agr_, row.names,
 		st_agr(x) = agr[match(setdiff(names(x), sf_column), names(agr))]
 		x
 	} else
-		as.data.frame(x)
+		structure(x, class = setdiff(class(x), "sf"))
 }
 
 #' @export
