@@ -45,12 +45,14 @@ static void __warningHandler(const char *fmt, ...) {
 	return;
 }
 
+// #nocov start
 static void __countErrorHandler(const char *fmt, void *userdata) {
 	int *i = (int *) userdata;
 	*i = *i + 1;
 }
 
 static void __emptyNoticeHandler(const char *fmt, void *userdata) { }
+// #nocov end
 
 GEOSContextHandle_t CPL_geos_init(void) {
 #ifdef HAVE350
@@ -75,7 +77,11 @@ std::vector<GEOSGeom> geometries_from_sfc(GEOSContextHandle_t hGEOSCtxt, Rcpp::L
 
 	double precision = sfc.attr("precision");
 
-	Rcpp::List wkblst = CPL_write_wkb(sfc, true, native_endian(), get_dim_sfc(sfc, dim), precision);
+	Rcpp::CharacterVector cls = get_dim_sfc(sfc, dim);
+	if (cls[0] == "XYM" || cls[0] == "XYZM")
+		Rcpp::stop("GEOS does not support XYM or XYZM geometries; use st_zm() to drop M\n"); // #nocov
+
+	Rcpp::List wkblst = CPL_write_wkb(sfc, true, native_endian(), cls, precision);
 	std::vector<GEOSGeom> g(sfc.size());
 	GEOSWKBReader *wkb_reader = GEOSWKBReader_create_r(hGEOSCtxt);
 	for (int i = 0; i < sfc.size(); i++) {
@@ -154,7 +160,7 @@ log_fn which_geom_fn(const std::string op) {
 		return GEOSCovers_r;
 	else if (op == "covered_by")
 		return GEOSCoveredBy_r;
-	throw std::range_error("wrong value for op"); // unlikely to happen unless user wants to
+	throw std::range_error("wrong value for op"); // unlikely to happen unless user wants to #nocov
 }
 
 log_prfn which_prep_geom_fn(const std::string op) {
@@ -180,7 +186,7 @@ log_prfn which_prep_geom_fn(const std::string op) {
 		return GEOSPreparedCovers_r;
 	else if (op == "covered_by")
 		return GEOSPreparedCoveredBy_r;
-	throw std::range_error("wrong value for op"); // unlikely to happen unless user wants to
+	throw std::range_error("wrong value for op"); // unlikely to happen unless user wants to #nocov
 }
 
 // [[Rcpp::export]]
@@ -246,7 +252,7 @@ Rcpp::List CPL_geos_binop(Rcpp::List sfc0, Rcpp::List sfc1, std::string op, doub
 					rowi(j) = chk_(GEOSRelatePattern_r(hGEOSCtxt, gmv0[i], gmv1[j], 
 						pattern.c_str()));
 				if (! sparse)
-					densemat(i,_) = rowi;
+					densemat(i,_) = rowi; // #nocov
 				else
 					sparsemat[i] = get_which(rowi);
 				R_CheckUserInterrupt();
@@ -302,7 +308,7 @@ Rcpp::CharacterVector CPL_geos_is_valid_reason(Rcpp::List sfc) {
 	for (int i = 0; i < out.length(); i++) {
 		char *buf = GEOSisValidReason_r(hGEOSCtxt, gmv[i]);
 		if (buf == NULL)
-			out[i] = NA_STRING;
+			out[i] = NA_STRING; // #nocov
 		else {
 			out[i] = buf;
 			GEOSFree_r(hGEOSCtxt, buf);
@@ -320,7 +326,7 @@ Rcpp::LogicalVector CPL_geos_is_valid(Rcpp::List sfc, bool NA_on_exception = tru
 	int notice = 0;
 	if (NA_on_exception) {
 		if (sfc.size() > 1)
-			throw std::range_error("NA_on_exception will only work reliably with length 1 sfc objects");
+			throw std::range_error("NA_on_exception will only work reliably with length 1 sfc objects"); // #nocov
 #ifdef HAVE350
 		GEOSContext_setNoticeMessageHandler_r(hGEOSCtxt, 
 			(GEOSMessageHandler_r) __emptyNoticeHandler, (void *) &notice);
@@ -338,7 +344,7 @@ Rcpp::LogicalVector CPL_geos_is_valid(Rcpp::List sfc, bool NA_on_exception = tru
 	for (int i = 0; i < out.length(); i++) {
 		int ret = GEOSisValid_r(hGEOSCtxt, gmv[i]);
 		if (NA_on_exception && (ret == 2 || notice != 0))
-			out[i] = NA_LOGICAL; // no need to set notice back here, as we only consider 1 geometry
+			out[i] = NA_LOGICAL; // no need to set notice back here, as we only consider 1 geometry #nocov
 		else
 			out[i] = chk_(ret);
 		GEOSGeom_destroy_r(hGEOSCtxt, gmv[i]);
@@ -384,7 +390,6 @@ Rcpp::List CPL_geos_union(Rcpp::List sfc, bool by_feature = false) {
 	return out;
 }
 
-
 GEOSGeometry *chkNULL(GEOSGeometry *value) {
 	if (value == NULL)
 		throw std::range_error("GEOS exception"); // #nocov
@@ -415,9 +420,9 @@ Rcpp::List CPL_geos_op(std::string op, Rcpp::List sfc,
 	} else if (op == "convex_hull") {
 		for (size_t i = 0; i < g.size(); i++)
 			out[i] = chkNULL(GEOSConvexHull_r(hGEOSCtxt, g[i]));
-	} else if (op == "unary_union") {
-		for (size_t i = 0; i < g.size(); i++)
-			out[i] = chkNULL(GEOSUnaryUnion_r(hGEOSCtxt, g[i]));
+//	} else if (op == "unary_union") { // -> done by CPL_geos_union()
+//		for (size_t i = 0; i < g.size(); i++)
+//			out[i] = chkNULL(GEOSUnaryUnion_r(hGEOSCtxt, g[i]));
 	} else if (op == "simplify") {
 		for (size_t i = 0; i < g.size(); i++)
 			out[i] = preserveTopology ? chkNULL(GEOSTopologyPreserveSimplify_r(hGEOSCtxt, g[i], dTolerance)) :
@@ -593,7 +598,7 @@ Rcpp::List CPL_invert_sparse_incidence(Rcpp::List m, int n) {
 		Rcpp::IntegerVector v = m[i];
 		for (int j = 0; j < v.size(); j++) {
 			if (v[j] > n || v[j] < 0)
-				throw std::range_error("CPL_invert_sparse: index out of bounds");
+				throw std::range_error("CPL_invert_sparse: index out of bounds"); // #nocov
 			sizes[v[j] - 1] += 1; // count
 		}
 	}
