@@ -91,3 +91,9 @@ st_intersects(x, x, sparse = FALSE)
 # two empty geoms:
 x = st_sfc(st_multipoint(), st_linestring())
 st_intersects(x, x, sparse = FALSE)
+
+# write & read:
+x = st_sf(a = 2:1, geometry = st_sfc(st_linestring(), st_linestring(matrix(1:4,2))))
+write_sf(x, "empty.shp")
+y = read_sf("empty.shp")
+all.equal(x, y)
