@@ -79,15 +79,29 @@ if ("SQLite" %in% st_drivers()$name && require(RSQLite)) {
 	m$GEOMETRY = st_as_sfc(m$GEOMETRY, spatialite = FALSE) # ISO wkb
 	print(st_sf(m), n = 3)
 
-	db = system.file("sqlite/test3.sqlite", package = "sf")
-	dbcon <- dbConnect(dbDriver("SQLite"), db)
-	m = dbReadTable(dbcon, "HighWays")
-	m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
-	print(st_sf(m), n = 3)
-	m = dbReadTable(dbcon, "Towns")
-	m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
-	print(st_sf(m), n = 3)
-	m = dbReadTable(dbcon, "Regions")
-	m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
-	print(st_sf(m), n = 3)
+	db = system.file("sqlite/b.sqlite", package = "sf") # has an INT8 field
+	b = st_read(db)
+	print(b)
+	b = st_read(db, int64_as_string=TRUE)
+	print(b)
+
+	if (.Platform$endian == "little") {
+	  db = system.file("sqlite/test3.sqlite", package = "sf")
+	  dbcon <- dbConnect(dbDriver("SQLite"), db)
+	  m = dbReadTable(dbcon, "HighWays")
+	  m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
+	  print(st_sf(m), n = 3)
+	  m = dbReadTable(dbcon, "Towns")
+	  m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
+	  print(st_sf(m), n = 3)
+	  m = dbReadTable(dbcon, "Regions")
+	  m$Geometry = st_as_sfc(m$Geometry, spatialite = TRUE) # spatialite wkb
+	  print(st_sf(m), n = 3)
+	}
 }
+
+csv = system.file("csv/pt.csv", package = "sf")
+identical(st_read(quiet = TRUE, csv, options = "AUTODETECT_TYPE=Yes")$Int64[3], NA_real_)
+identical(st_read(quiet = TRUE, csv, int64_as_string = TRUE, stringsAsFactors = FALSE,
+	options = "AUTODETECT_TYPE=Yes")$Int64[3], NA_character_)
+identical(st_read(quiet = TRUE, csv, options = "AUTODETECT_TYPE=Yes")$Int32[3], NA_integer_)
